@@ -27,6 +27,7 @@ psiClayton <- function(copula, s) {
 }
 
 claytonCopula <- function(param = NA_real_, dim = 2L) {
+  stopifnot(length(param) == 1)
   ## get expressions of cdf and pdf
   cdfExpr <- function(n) {
     expr <- "u1^(-alpha) - 1"
@@ -46,13 +47,13 @@ claytonCopula <- function(param = NA_real_, dim = 2L) {
     val
   }
 
-  if ((dim <- as.integer(dim)) > 2 && param[1] < 0)
+  if((dim <- as.integer(dim)) > 2 && !is.na(param) && param < 0)
     stop("param can be negative only for dim = 2")
   cdf <- cdfExpr(dim)
   pdf <- if (dim <= 6) pdfExpr(cdf, dim) # else NULL
   new("claytonCopula",
       dimension = dim,
-      parameters = param[1],
+      parameters = param,
       exprdist = c(cdf = cdf, pdf = pdf),
       param.names = "param",
       param.lowbnd = if(dim == 2) -1 else 0,
