@@ -69,7 +69,7 @@ setMethod("show", signature("fitCopula"),
 fitCopula <- function(copula, data, method = c("mpl","ml","itau","irho"),
                       start = NULL, lower = NULL, upper = NULL,
                       optim.method = "BFGS", optim.control = list(maxit=1000),
-                      estimate.variance = TRUE, hideWarnings = TRUE)
+                      estimate.variance = TRUE, hideWarnings = FALSE)
 {
   if(!is.matrix(data)) {
     warning("coercing 'data' to a matrix.")
@@ -415,6 +415,8 @@ varPL <- function(cop,u)
 ## variance of the estimator based on Kendall's tau ############################
 
 ## copula is the FITTED copula
+
+## Currently "unfinished";  instead  L <- .....(X)   where X <- getXmat() below
 getL <- function(copula) {
   ## for ellipCopula only
   p <- copula@dimension
